Api
====

Modules Summary:

.. toctree::
   :maxdepth: 1

   umbra.components.addons.projectsExplorer.models <api/umbra.components.addons.projectsExplorer.models>
   umbra.components.addons.projectsExplorer.projectsExplorer <api/umbra.components.addons.projectsExplorer.projectsExplorer>
   umbra.components.addons.projectsExplorer.views <api/umbra.components.addons.projectsExplorer.views>
   umbra.components.addons.tcpClientUi.tcpClientUi <api/umbra.components.addons.tcpClientUi.tcpClientUi>
   umbra.components.addons.tcpServerUi.tcpServerUi <api/umbra.components.addons.tcpServerUi.tcpServerUi>
   umbra.components.addons.traceUi.models <api/umbra.components.addons.traceUi.models>
   umbra.components.addons.traceUi.nodes <api/umbra.components.addons.traceUi.nodes>
   umbra.components.addons.traceUi.traceUi <api/umbra.components.addons.traceUi.traceUi>
   umbra.components.addons.traceUi.views <api/umbra.components.addons.traceUi.views>
   umbra.components.factory.componentsManagerUi.componentsManagerUi <api/umbra.components.factory.componentsManagerUi.componentsManagerUi>
   umbra.components.factory.componentsManagerUi.models <api/umbra.components.factory.componentsManagerUi.models>
   umbra.components.factory.componentsManagerUi.nodes <api/umbra.components.factory.componentsManagerUi.nodes>
   umbra.components.factory.componentsManagerUi.views <api/umbra.components.factory.componentsManagerUi.views>
   umbra.components.factory.preferencesManager.preferencesManager <api/umbra.components.factory.preferencesManager.preferencesManager>
   umbra.components.factory.scriptEditor.editor <api/umbra.components.factory.scriptEditor.editor>
   umbra.components.factory.scriptEditor.editorStatus <api/umbra.components.factory.scriptEditor.editorStatus>
   umbra.components.factory.scriptEditor.models <api/umbra.components.factory.scriptEditor.models>
   umbra.components.factory.scriptEditor.nodes <api/umbra.components.factory.scriptEditor.nodes>
   umbra.components.factory.scriptEditor.scriptEditor <api/umbra.components.factory.scriptEditor.scriptEditor>
   umbra.components.factory.scriptEditor.searchAndReplace <api/umbra.components.factory.scriptEditor.searchAndReplace>
   umbra.components.factory.scriptEditor.searchInFiles <api/umbra.components.factory.scriptEditor.searchInFiles>
   umbra.components.factory.scriptEditor.views <api/umbra.components.factory.scriptEditor.views>
   umbra.components.factory.scriptEditor.workers <api/umbra.components.factory.scriptEditor.workers>
   umbra.engine <api/umbra.engine>
   umbra.exceptions <api/umbra.exceptions>
   umbra.globals.constants <api/umbra.globals.constants>
   umbra.globals.runtimeGlobals <api/umbra.globals.runtimeGlobals>
   umbra.globals.uiConstants <api/umbra.globals.uiConstants>
   umbra.launcher <api/umbra.launcher>
   umbra.managers.actionsManager <api/umbra.managers.actionsManager>
   umbra.managers.fileSystemEventsManager <api/umbra.managers.fileSystemEventsManager>
   umbra.managers.layoutsManager <api/umbra.managers.layoutsManager>
   umbra.managers.notificationsManager <api/umbra.managers.notificationsManager>
   umbra.managers.patchesManager <api/umbra.managers.patchesManager>
   umbra.preferences <api/umbra.preferences>
   umbra.processing <api/umbra.processing>
   umbra.reporter <api/umbra.reporter>
   umbra.ui.common <api/umbra.ui.common>
   umbra.ui.completers <api/umbra.ui.completers>
   umbra.ui.delegates <api/umbra.ui.delegates>
   umbra.ui.highlighters <api/umbra.ui.highlighters>
   umbra.ui.inputAccelerators <api/umbra.ui.inputAccelerators>
   umbra.ui.languages <api/umbra.ui.languages>
   umbra.ui.models <api/umbra.ui.models>
   umbra.ui.nodes <api/umbra.ui.nodes>
   umbra.ui.themes <api/umbra.ui.themes>
   umbra.ui.views <api/umbra.ui.views>
   umbra.ui.visualAccelerators <api/umbra.ui.visualAccelerators>
   umbra.ui.widgets.active_QLabel <api/umbra.ui.widgets.active_QLabel>
   umbra.ui.widgets.active_QLabelsCollection <api/umbra.ui.widgets.active_QLabelsCollection>
   umbra.ui.widgets.application_QToolBar <api/umbra.ui.widgets.application_QToolBar>
   umbra.ui.widgets.basic_QPlainTextEdit <api/umbra.ui.widgets.basic_QPlainTextEdit>
   umbra.ui.widgets.codeEditor_QPlainTextEdit <api/umbra.ui.widgets.codeEditor_QPlainTextEdit>
   umbra.ui.widgets.delayed_QSplashScreen <api/umbra.ui.widgets.delayed_QSplashScreen>
   umbra.ui.widgets.messageBox <api/umbra.ui.widgets.messageBox>
   umbra.ui.widgets.notification_QLabel <api/umbra.ui.widgets.notification_QLabel>
   umbra.ui.widgets.search_QLineEdit <api/umbra.ui.widgets.search_QLineEdit>
   umbra.ui.widgets.variable_QPushButton <api/umbra.ui.widgets.variable_QPushButton>
